@@ -60,8 +60,11 @@ class PackagesViewModel(
             shizukuManager.checkShizukuStatus()
 
             // If Shizuku is available but permission not granted, request it
+            // BUT: Skip if user already denied to prevent prompt spam (Issue #68)
             if (shizukuManager.isShizukuAvailable() && !shizukuManager.hasShizukuPermission) {
-                shizukuManager.requestShizukuPermission()
+                if (!shizukuManager.hasUserDeniedPermission) {
+                    shizukuManager.requestShizukuPermission()
+                }
             }
 
             // Also check root as fallback
@@ -108,11 +111,11 @@ class PackagesViewModel(
             return
         }
 
-        // Clear packages and update filter state immediately
+        // Set loading state but keep existing packages visible to preserve scroll position
+        // DiffUtil will handle smooth transition when new data arrives
         _uiState.value = _uiState.value.copy(
             isLoadingData = true,
             isRenderingUI = false,
-            packages = emptyList(),
             filterState = filterState
         )
 
